YARP 2.3.14 (2011-12-13)                                              {#v2_3_14}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.12...v2.3.14`):

```
    70  Ali Paikan <ali.paikan@iit.it>
    47  Paul Fitzpatrick <paulfitz@alum.mit.edu>
    36  Lorenzo Natale <lorenzo.natale@iit.it>
     7  Ugo Pattacini <ugo.pattacini@iit.it>
     3  Alessandro Scalzo <alessandro.scalzo@iit.it>
     2  Duarte Aragao <daragao@gmail.com>
     2  Marco Randazzo <marco.randazzo@iit.it>
     1  Andrea Del Prete <andrea.delprete@iit.it>
```
